@@ -9,7 +9,7 @@ import pyarrow as pa
 import unicodedata
 
 from pecab._datrie import DoubleArrayTrie
-from pecab._resources.unknown import UNK
+from pecab._utils._unknown import UNK
 from pecab._tokens import DictionaryToken, TokenAttributes, DecompoundToken
 from pecab._user_dict import UserDictionary
 from pecab._utils._char_definition import CharacterDefinition, character_category_map
@@ -29,7 +29,7 @@ class Tokenizer:
             words=self.load_arrow("words.arrow"),
         )
         self.conn_costs = np.memmap(
-            os.path.join(PATH, "_resources", "mmap", "matrix.npy"),
+            os.path.join(PATH, "_resources", "matrix.npy"),
             mode="r+",
             dtype="int16",
             shape=Tokenization.CONN_SHAPE,
@@ -47,7 +47,7 @@ class Tokenizer:
     def load_arrow(filename):
         return pa.ipc.RecordBatchFileReader(
             pa.memory_map(
-                os.path.join(PATH, "_resources", "mmap", filename),
+                os.path.join(PATH, "_resources", filename),
                 mode="r",
             )
         ).read_all()
